@@ -1,6 +1,6 @@
 package App::Greple::xlate::gpt4;
 
-our $VERSION = "0.30";
+our $VERSION = "0.31";
 
 use v5.14;
 use warnings;
@@ -17,18 +17,35 @@ use App::Greple::xlate::Lang qw(%LANGNAME);
 our $lang_from //= 'ORIGINAL';
 our $lang_to   //= 'JA';
 our $auth_key;
-our $method = 'gpt4';
+our $method = __PACKAGE__ =~ s/.*://r;
 
 my %param = (
-    gpt4 => { engine => 'gpt-4-1106-preview', temp => '0.0', max => 1000, sub => \&gpty },
+    gpt3 => { engine => 'gpt-3.5-turbo', temp => '0.0', max => 3000, sub => \&gpty,
+	      prompt => 'Translate following entire text into %s, line-by-line.',
+	  },
+    gpt4 => { engine => 'gpt-4-1106-preview', temp => '0.0', max => 3000, sub => \&gpty,
+	      prompt => 'Translate following entire text into %s, line-by-line.',
+	  },
 );
 
+sub initialize {
+    my($mod, $argv) = @_;
+    $mod->setopt(default => "-Mxlate --xlate-engine=$method");
+}
+
 sub gpty {
     state $gpty = App::cdif::Command->new;
     my $text = shift;
     my $param = $param{$method};
-    my $system = sprintf("Translate following entire text into %s, line-by-line.",
-			 $LANGNAME{$lang_to} // die "$lang_to: unknown lang.\n");
+    my $prompt = opt('prompt') || $param->{prompt};
+    my @vars = do {
+	if ($prompt =~ /%s/) {
+	    $LANGNAME{$lang_to} // die "$lang_to: unknown lang.\n"
+	} else {
+	    ();
+	}
+    };
+    my $system = sprintf($prompt, @vars);
     my @command = (
 	'gpty',
 	-e => $param->{engine},
@@ -61,6 +78,9 @@ sub xlate {
     my @from = map { /\n\z/ ? $_ : "$_\n" } @_;
     my @to;
     my $max = $App::Greple::xlate::max_length || $param{$method}->{max} // die;
+    if (my @len = grep { $_ > $max } map length, @from) {
+	die "Contain lines longer than max length (@len > $max).\n";
+    }
     while (@from) {
 	my @tmp;
 	my $len = 0;
@@ -70,6 +90,7 @@ sub xlate {
 	    $len += $next;
 	    push @tmp, shift @from;
 	}
+	@tmp > 0 or die "Probably text is longer than max length ($max).\n";
 	push @to, xlate_each @tmp;
     }
     @to;
@@ -79,4 +100,5 @@ sub xlate {
 
 __DATA__
 
-option default -Mxlate --xlate-engine=gpt4
+# set in &initialize()
+# option default -Mxlate --xlate-engine=gptN
