@@ -3,6 +3,10 @@
 (defvar xlate-default-target-lang "EN-US"
   "Default target language for translation.")
 
+(defvar xlate-lang-aliases
+  '(("EN" . "EN-US"))
+  "Alias table for language codes.")
+
 (defvar xlate-languages
   '("BG" "CS" "DA" "DE" "EL" "EN-GB" "EN-US" "ES" "ET" "FI"
     "FR" "HU" "ID" "IT" "JA" "KO" "LT" "LV" "NB" "NL" "PL"
@@ -22,12 +26,14 @@ If called with a prefix argument (C-u), prompt for the target language."
   (interactive
    (list (region-beginning) (region-end)
          (if current-prefix-arg
-             (completing-read (format "Target language (default: %s): "
-                                      xlate-default-target-lang)
-                              xlate-languages nil t nil
-			      xlate-default-target-lang xlate-default-target-lang)
+             (let ((langs (append xlate-languages (mapcar 'car xlate-lang-aliases))))
+               (completing-read (format "Target language (default: %s): "
+                                        xlate-default-target-lang)
+                                langs nil t nil
+                                xlate-default-target-lang xlate-default-target-lang))
            nil)))
-  (let ((lang (or target-lang xlate-default-target-lang)))
+  (let* ((l (or target-lang xlate-default-target-lang))
+         (lang (or (cdr (assoc lang xlate-lang-aliases)) l)))
     (shell-command-on-region
      begin end
      (format "xlate -a -s -o cm -w72 -p '(?s).+' -t %s -" lang)
